--[[
******************************************************************
Script to copy the online documentation files to a known location where they can
be found by various driver components.

 ***** IMPORTANT NOTE *****
When this script is called at install time the calling script should set bOverwriteFiles to true.
This script should not be called at uninstall time.
******************************************************************
]]--

fDebug("\r\nCopying documentation...");
-- initialize local variables.
local bContinue = true;
local error = 0;
local pathCommonAppDataFolder = Shell.GetFolder(SHF_APPLICATIONDATA_COMMON);
local pathRootDriverFolder = pathCommonAppDataFolder.."\\Datacard\\XPS Card Printer";
local pathDocuments = pathRootDriverFolder.."\\Documentation";
-- local strDocShortcutName = "My Datacard XPS Card Printer";

-- Make sure the overwrite flag is set to a valid state (true).
-- This protects against callers not implementing this variable and having its value be nil.
if (bOverwriteFiles ~= false) then
	bOverwriteFiles = true;
end
		
--[[
******************************************************************
Create folder to hold the documentation files. 
******************************************************************
 ]]--	
if not (Folder.DoesExist(pathDocuments)) then
	Folder.Create(pathDocuments);
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("Creating documentation folder at "..pathDocuments.." failed with error: "..error);
	end	
end

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
--   Folders created... Next, copy all documentation files
-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

-- StatusDlg.Show(MB_ICONNONE, false);

--[[
******************************************************************
Copy the documentation files. 
******************************************************************
 ]]--	
 
if bContinue then
	File.Copy(_SourceFolder.."\\Documentation\\*.*", pathDocuments, true, bOverwriteFiles, false, false, nil);
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("Copying documentation file to "..pathDocuments.." failed with error: "..error);
	else
		Shell.CreateShortcut(_DesktopFolderCommon, strDocShortcutName, pathDocuments.."\\MyXPSCardPrinter.exe", "", "", pathDocuments.."\\MyXPSCardPrinter.ico", 0, SW_SHOWNORMAL, nil);
	end
end	

-- StatusDlg.Hide(); -- files have been copied.

-- Send a signal back to the main script using the bContinueInstall flag.
if (bContinue) then
	bContinueInstall = true;
	fDebug("SUCCESS: Documentation copied to "..pathDocuments);
else
	bContinueInstall = false;
	fDebug("FAIL: Documentation not copied.");
end
